@@ -49,7 +49,7 @@ class AKIFlagger:
         add_min_creat (boolean): **default False.** Whether or not to add the minimum creatinine column from rolling-window method.
         
     '''
-    def __init__(self, patient_id = 'mrn', creatinine = 'creatinine', time = 'time', inpatient = 'inpatient', # Required columns
+    def __init__(self, patient_id = 'patient_id', creatinine = 'creatinine', time = 'time', inpatient = 'inpatient', # Required columns
                  encounter_id = 'enc', admission = 'admission', baseline_creat = 'baseline_creat', # Helpful columns, imputed otherwise
                  age = 'age', sex = 'sex', race = 'race',  # Required if CKD-EPI imputation is wanted
                  padding = None, HB_trumping = False, eGFR_impute = False, # Main parameters
